@@ -1,6 +1,6 @@
 package ETL::Yertl;
 # ABSTRACT: ETL with a Shell
-$ETL::Yertl::VERSION = '0.019';
+$ETL::Yertl::VERSION = '0.020';
 use strict;
 use warnings;
 use base 'Import::Base';
@@ -55,7 +55,7 @@ ETL::Yertl - ETL with a Shell
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -71,6 +71,12 @@ version 0.019
     $ yto csv work.yml
     $ yto json work.yml
 
+    # Read data from a database
+    $ ysql query devdb 'SELECT * FROM employee'
+
+    # Write data to a database
+    $ ysql query devdb 'INSERT INTO employee ( id, name ) VALUES ( $.id, $.name )'
+
     ### In Perl...
     use ETL::Yertl;
 
@@ -100,18 +106,38 @@ Yertl will have tools for:
 
 =head1 SEE ALSO
 
+=over 4
+
+=item L<http://preaction.github.io/ETL-Yertl>
+
+The Yertl home page.
+
+=back
+
 =head2 Yertl Tools
 
 =over 4
 
 =item L<yfrom>
 
+Convert incoming data (CSV, JSON) to Yertl documents.
+
 =item L<yto>
 
+Convert Yertl documents into another format (CSV, JSON).
+
+=item L<ysql>
+
+Read/write documents from SQL databases.
+
 =item L<ymask>
 
+Filter documents with a mask, letting only matching fields through.
+
 =item L<yq>
 
+A powerful mini-language for munging and filtering.
+
 =back
 
 =head2 Other Tools
